==> nextcloud-app-mail-5.5.11-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/uz.js <==
OC.L10N.register(
    "mail",
    {
    "Work" : "Ish",
    "Personal" : "Personal",
    "Later" : "Keyinchalik",
    "Mail" : "Mail",
    "Save" : "Saqlash",
    "Connect" : "Connect",
    "Name" : "Name",
    "Password" : "Password",
    "None" : "Yo'q",
    "Email address" : "E-pochta manzili",
    "Cancel" : "Bekor qilish",
    "General" : "Umumiy",
    "Appearance" : "Tashqi ko'rinish",
    "List" : "Ro`yxat",
    "Register" : "Roʻyxatdan oʻtish",
    "Security" : "Xavfsizlik",
    "About" : "About",
    "Keyboard shortcuts" : "Klaviatura yorliqlari",
    "Archive" : "Arxiv",
    "Delete" : "O'chirish",
    "Search" : "Qidirish",
    "Send" : "Send",
    "Refresh" : "Refresh",
    "Ok" : "Yaxshi",
    "From" : "Dan",
    "To" : "Gacha",
    "Choose" : "Choose",
    "Choose a file to add as attachment" : "Ilova sifatida qo'shish uchun faylni tanlang",
    "Choose a file to share as a link" : "Havola sifatida almashish uchun faylni tanlang",
    "_{count} attachment_::_{count} attachments_" : ["{count} qo'shimchalar"],
    "Confirm" : "Confirm",
    "Favorite" : "Favorite",
    "More actions" : "Ko'proq harakatlar",
    "Back" : "Orqaga",
    "Create event" : "Tadbir yaratish",
    "All day" : "Butun kun",
    "Attendees" : "Ishtirokchilar",
    "Description" : "Tavsif",
    "Create" : "Yaratish",
    "Select" : "Select",
    "Comment" : "Izoh",
    "Accept" : "Qabul qiling",
    "Decline" : "Rad etish",
    "More options" : "Boshqa variantlar",
    "Remove" : "O'chirish",
    "email" : "email",
    "Today" : "Bugun",
    "Yesterday" : "Kecha",
    "Last week" : "O`tgan yil",
    "Last month" : "Oxirgi oy",
    "Other" : "Boshqa",
    "Translate" : "Tarjima",
    "Move" : "Move",
    "Remove {email}" : " {email} ni o'chirish",
    "Folder name" : "Jild nomi",
    "Saving" : "Saving",
    "Delete folder" : "Jildni o'chirish",
    "Rename" : "Nomini o'zgartirish",
    "Subscribed" : "Obuna boʻlgan",
    "Reply" : "Javob bering",
    "Retry" : "Qayta urinish",
    "Add" : "Add",
    "Close" : "Yopish",
    "Date" : "Sana",
    "Tags" : "Tags",
    "Last 7 days" : "Oxirgi 7 kun",
    "Custom" : "Boshqa",
    "Add tag" : "Teg qo'shing",
    "Not found" : "Topilmadi",
    "Untitled event" : "Nomsiz tadbir",
    "(organizer)" : "(tashkilotchi)",
    "Help" : "Yordam",
    "contains" : "o'z ichiga oladi",
    "Actions" : "Faolliklar",
    "Edit" : "Tahrirlash",
    "Reset" : "Qayta tiklash",
    "Client ID" : "Mijoz identifikatori",
    "Port" : "Port",
    "Submit" : "Submit",
    "Shared" : "Ulashilgan",
    "Account connected" : "Akkaunt ulangan",
    "All" : "All",
    "Favorites" : "Favorites",
    "Error while sharing file" : "Fayl almashishda xatolik yuz berdi",
    "Continue to %s" : " %sni davom eting",
    "Accounts" : "Akkaunt"
},
"nplurals=1; plural=0;");

==> nextcloud-app-mail-5.5.15-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/uz.js <==
OC.L10N.register(
    "mail",
    {
    "Work" : "Ish",
    "Personal" : "Personal",
    "Later" : "Keyinchalik",
    "Mail" : "Mail",
    "Save" : "Saqlash",
    "Connect" : "Connect",
    "Name" : "Name",
    "Password" : "Password",
    "None" : "Yo'q",
    "Email address" : "E-pochta manzili",
    "Cancel" : "Bekor qilish",
    "General" : "Umumiy",
    "Appearance" : "Tashqi ko'rinish",
    "List" : "Ro`yxat",
    "Register" : "Roʻyxatdan oʻtish",
    "Security" : "Xavfsizlik",
    "Keyboard shortcuts" : "Klaviatura yorliqlari",
    "Archive" : "Arxiv",
    "Delete" : "O'chirish",
    "Search" : "Qidirish",
    "Send" : "Send",
    "Refresh" : "Refresh",
    "About" : "About",
    "Ok" : "Yaxshi",
    "From" : "Dan",
    "To" : "Gacha",
    "Choose" : "Choose",
    "Choose a file to add as attachment" : "Ilova sifatida qo'shish uchun faylni tanlang",
    "Choose a file to share as a link" : "Havola sifatida almashish uchun faylni tanlang",
    "_{count} attachment_::_{count} attachments_" : ["{count} qo'shimchalar"],
    "Confirm" : "Confirm",
    "Favorite" : "Favorite",
    "More actions" : "Ko'proq harakatlar",
    "Back" : "Orqaga",
    "Create event" : "Tadbir yaratish",
    "All day" : "Butun kun",
    "Attendees" : "Ishtirokchilar",
    "Description" : "Tavsif",
    "Create" : "Yaratish",
    "Select" : "Select",
    "Comment" : "Izoh",
    "Accept" : "Qabul qiling",
    "Decline" : "Rad etish",
    "More options" : "Boshqa variantlar",
    "Remove" : "O'chirish",
    "email" : "email",
    "Today" : "Bugun",
    "Yesterday" : "Kecha",
    "Last week" : "O`tgan yil",
    "Last month" : "Oxirgi oy",
    "Other" : "Boshqa",
    "Translate" : "Tarjima",
    "Move" : "Move",
    "Remove {email}" : " {email} ni o'chirish",
    "Folder name" : "Jild nomi",
    "Saving" : "Saving",
    "Delete folder" : "Jildni o'chirish",
    "Rename" : "Nomini o'zgartirish",
    "Subscribed" : "Obuna boʻlgan",
    "Reply" : "Javob bering",
    "Retry" : "Qayta urinish",
    "Add" : "Add",
    "Close" : "Yopish",
    "Date" : "Sana",
    "Tags" : "Tags",
    "Last 7 days" : "Oxirgi 7 kun",
    "Custom" : "Boshqa",
    "Add tag" : "Teg qo'shing",
    "Not found" : "Topilmadi",
    "Untitled event" : "Nomsiz tadbir",
    "(organizer)" : "(tashkilotchi)",
    "Help" : "Yordam",
    "contains" : "o'z ichiga oladi",
    "Actions" : "Faolliklar",
    "Edit" : "Tahrirlash",
    "Reset" : "Qayta tiklash",
    "Client ID" : "Mijoz identifikatori",
    "Port" : "Port",
    "Submit" : "Submit",
    "Shared" : "Ulashilgan",
    "Account connected" : "Akkaunt ulangan",
    "All" : "All",
    "Favorites" : "Favorites",
    "Error while sharing file" : "Fayl almashishda xatolik yuz berdi",
    "Continue to %s" : " %sni davom eting",
    "Accounts" : "Akkaunt",
    "Loading …" : "Yuklanmoqda…"
},
"nplurals=1; plural=0;");
